
medspacy-io
------------

medspacy-io is a collection of modules to facilitate reading text from various sources and writing to various sources.


Installation
------------

    pip install medspacy-io


How to use
------------

Please refer to the samples in the tests.

A Colab notebook demo is available at:

https://colab.research.google.com/drive/12EBOaKej9uPmGAb5dV2oB1goEWrwXjSD
    

